==> claromentis-framework-9.6.6-26891208.zip: web/intranet/comments/tests/mocks/CommentableNewsMock.php <==
<?php
namespace Claromentis\Comments\Tests;

$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array("_9bffee00648893b4251c5924" . "7468f168" => base64_decode("MT" . "0x"));
use Claromentis\Comments\CommentableInterface;
use Claromentis\Comments\Model\Comment;
use Claromentis\Comments\Notification\Notification;
use Claromentis\Comments\SupportedOptions;
use Claromentis\Core\DAL;
use Claromentis\Core\Security\SecurityContext;
class CommentableNewsMock implements CommentableInterface
{
    public $id;
    public $has_perms = true;
    
    
    
    
    
    
    
    
    
    public function Load($_0ea4e32b57963ac0cb3057e03e9aef64, $_4a033bdf0ce701c6255d5238633ab2d0 = array())
    {
        $this->id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        $this->has_perms = (bool) ($_0ea4e32b57963ac0cb3057e03e9aef64 % 2);
    }
    
    
    
    
    
    
    public function GetAggregationObject()
    {
        $_68ffaaa31e3ba49ed9d6159fbee9f043 = new NewsAggregationMock();
        $_68ffaaa31e3ba49ed9d6159fbee9f043->id = $this->id;
        return $_68ffaaa31e3ba49ed9d6159fbee9f043;
    }
    
    
    
    
    
    
    public function GetSQLFilter()
    {
        return new DAL\QueryPart($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_9bffee00648893b4251c59247468" . "f168"]);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function UserHasPermission(SecurityContext $context, $perms, Comment $comment = null)
    {
        return $this->has_perms;
    }
    
    
    
    
    
    
    
    public function GetOptions()
    {
        return [SupportedOptions::REPLIES => true, SupportedOptions::LIKES => true, SupportedOptions::ATTACHMENTS => true];
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function Notify(Comment $comment, Notification $_0dfb4a13f8c551dff0f061eebc847961)
    {
        
        
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/comments/tests/mocks/CommentableNewsMock.php <==
<?php
namespace Claromentis\Comments\Tests;

$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] ?: array()) + array("_9bffee00" . "648893b42" . "51c592474" . "68f168" => base64_decode("M" . "T" . "0" . "x"));
use Claromentis\Comments\CommentableInterface;
use Claromentis\Comments\Model\Comment;
use Claromentis\Comments\Notification\Notification;
use Claromentis\Comments\SupportedOptions;
use Claromentis\Core\DAL;
use Claromentis\Core\Security\SecurityContext;
class CommentableNewsMock implements CommentableInterface
{
    public $id;
    public $has_perms = true;
    
    
    
    
    
    
    
    
    
    public function Load($_0ea4e32b57963ac0cb3057e03e9aef64, $_4a033bdf0ce701c6255d5238633ab2d0 = array())
    {
        $this->id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        $this->has_perms = (bool) ($_0ea4e32b57963ac0cb3057e03e9aef64 % 2);
    }
    
    
    
    
    
    
    public function GetAggregationObject()
    {
        $_68ffaaa31e3ba49ed9d6159fbee9f043 = new NewsAggregationMock();
        $_68ffaaa31e3ba49ed9d6159fbee9f043->id = $this->id;
        return $_68ffaaa31e3ba49ed9d6159fbee9f043;
    }
    
    
    
    
    
    
    public function GetSQLFilter()
    {
        return new DAL\QueryPart($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_9bffee00648" . "893b4251c592" . "47468f168"]);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function UserHasPermission(SecurityContext $context, $perms, Comment $comment = null)
    {
        return $this->has_perms;
    }
    
    
    
    
    
    
    
    public function GetOptions()
    {
        return [SupportedOptions::REPLIES => true, SupportedOptions::LIKES => true, SupportedOptions::ATTACHMENTS => true];
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function Notify(Comment $comment, Notification $_0dfb4a13f8c551dff0f061eebc847961)
    {
        
        
    }
}
